@import url('https://fonts.googleapis.com/css?family=Roboto');

html {
    line-height: normal;
}

main {
    min-height: 100vh;
}

p {
    font-size: 1.2em;
    font-weight: 300;
}

li {
    font-size: 1.2em;
    font-weight: 300;
}

h1 {
    font-size: 3.5rem;
    font-weight: 300;
}

h2 {
    font-size: 3.0rem;
    font-weight: 300;
}

h3 {
    font-size: 1.6rem;
    font-weight: 300;
}

h4 {
    font-size: 1.3rem;
    font-weight: 300;
}

h5 {
    font-size: 1.1rem;
}

.tabs {
    /* Materialize has a bug that shows the scrollbar sometimes, this prevents it */
    /*overflow-x: hidden;*/
}

td, tr {
    padding-right: 1px;
    padding-left: 1px;
    min-width: 40px;
}

/*.help-block {*/
/*    color: red;*/
/*}*/

.tight td {
    padding: 3px 3px;
}

.tighter {
    padding: 1px 1px;
}

.text-small {
    font-size: .75em;
}

.text-normal {
    font-size: 1em;
}

.text-right {
    text-align: right;
}

.text-center {
    text-align: center;
}

.info {
    color: red;
}

.single-line {
    white-space: nowrap;
}

.responsive-table-wrapper {
    overflow-x: auto;
    padding-bottom: 16px;
    /*min-width: 100%;
    max-width: 110%;
    margin: 0 -5%;*/
}

.autocomplete-content {
    opacity: .8;
    position: absolute;
    width: 100%;
}

.hidden {
    display: none;
}

.cell-collapsed {
    /* background: grey; */
    background-color: #f2f2f2;
}

.page-footer {
    margin-top: 50px;
}

.tabs .tab a {
    /*@extend .green .lighten-3;*/
    color: #a5d6a7;
}

.tabs .tab a:hover, .tabs .tab a.active {
    background-color: transparent;
    color: #66bb6a;
}

.tabs .tab.disabled a, .tabs .tab.disabled a:hover {
    color: rgba(165, 214, 167, 0.5);
}

.tabs .indicator {
    background-color: #66bb6a;
}

.tabs .tab a:focus, .tabs .tab a:focus.active {
    background-color: transparent;
}

/* Alerts */
.alert {
    padding: 5px;
    background-color: #dcedc8; /* light green lighten-4 */
    margin: 5px;
    border: solid #aed581 1px; /* light green lighten-2 */
    border-radius: 10px;
}

.alert-error {
    color: white;
    background-color: #f44336; /* red */
    border: solid #e57373 1px; /* red lighten-2 */
}

.alert-warning {
    background-color: #f0f4c3; /* lime lighten-4 */
    border: solid #dce775 1px; /* lime lighten-2 */
}

.messages.tags {
    font-weight: bold;
}

/* Override treetable icon */
table.treetable tr.collapsed span.indenter a {
    background-image: url('../img/_ionicons_svg_md-arrow-dropright.svg');
}

table.treetable tr.expanded span.indenter a {
    background-image: url('../img/_ionicons_svg_md-arrow-dropdown.svg');
}

/* Override Materialize container */
.container-app {
    margin: 0 auto;
    max-width: none;
    width: 95%;
}

@media only screen and (min-width: 601px) {
    .container-app {
        width: 95%;
    }
}

@media only screen and (min-width: 993px) {
    .container-app {
        width: 90%;
    }
}

.primary-color {
    color: #66bb6a;
}

.dark-color {
    color: #338a3e;
}

.light-color {
    color: #98ee99;
}

.btn-icon-round {
    border-radius: 50%;
    padding: 0 8px;
}

.file-field .btn, .file-field .btn-large, .file-field .btn-small {
    background-color: #66BB6A;
}

.btn-flat {
    background-color: #f5f5f5;
}

.btn-primary {
    background-color: #66BB6A;
}

.btn-warning {
    background-color: #F44336;
}

a.anchor {
    display: block;
    position: relative;
    top: -64px;
    visibility: hidden;
}

/* Specific Styling */
.part-info-form input {
    text-align: right;
}

.materialize-checkbox-padding div {
    padding: 14.5px 0;
}

/* Material dropdowns tighter */
.dropdown-content li > a, .dropdown-content li > span {
    padding: 6px;
    line-height: 16px;
}

.dropdown-content li {
    min-height: 30px;
}

/* table of contents styling */
/*#toc div.h1 { margin-left: 0 }*/
#toc li.h2 {
    margin-left: 0
}

#toc li.h3 {
    margin-left: 1em
}

#toc li.h4 {
    margin-left: 2em
}

#toc li.h5 {
    margin-left: 3em
}

/* Printer friendly */
.printer-show {
    display: none;
}

@media print {
    .container {
        width: 8.5in;
    }

    body {
        font-family: verdana, arial, sans-serif;
        /*transform: scale(.7);*/
        /*transform-origin: left top;*/
    }

    main {
        min-height: 0;
    }

    html {
        height: 100%;
    }

    .navbar-fixed {
        display: none;
    }

    .sidenav {
        display: none;
    }

    footer {
        display: none;
    }

    .printer-show {
        display: block;
    }

    .printer-hide {
        display: none;
    }

    .modal {
        display: none;
    }

    .dropdown-content {
        display: none;
    }

    .dropdown-trigger {
        display: none;
    }

    table {
        page-break-inside: avoid;
    }

    .pagination {
        display: none;
    }
}

/* --- Settings & Admin Layout Refinements (flat, Material-inspired) --- */
/* Scoped to .container-app so marketing pages and legacy views remain unchanged. */

/* Section spacing for denser admin/settings layouts */
.container-app .section {
    padding-top: 16px;
    padding-bottom: 16px;
}

/* Consistent section headers with optional leading/trailing icons */
.container-app .section-title {
    display: flex;
    align-items: center;
    gap: 8px;
    margin: 0 0 8px 0;
    letter-spacing: 0.2px;
    font-weight: 500;
}

.container-app .section-title .material-icons {
    line-height: 1;
}

.container-app .section-title img {
    height: 1.8rem;
    margin-left: 6px;
    vertical-align: middle;
}

/* When a service logo/image is used as a leading icon, adjust spacing */
.container-app .section-title img:first-child {
    margin-left: 0;
    margin-right: 6px;
}

/* Comfortable dividers between blocks */
.container-app .divider {
    margin: 16px 0;
}

/* Slightly smaller paragraph text and tighter rhythm in settings */
.container-app .section p {
    margin: 0 0 12px 0;
}

/* Tabs separation from content */
.container-app .tabs {
    margin-bottom: 12px;
}

/* Flat collections (used as key-value lists in settings) */
.container-app .collection.z-depth-0 {
    border: none;
}

.container-app .collection.z-depth-0 .collection-item {
    border: none;
    padding-left: 0;
}

/* Button group spacing in aligned action rows */
.container-app .right-align .btn,
.container-app .right-align .btn-flat {
    margin-left: 4px;
}