{% extends BASE_TEMPLATE %}

{# This template is for anything we want in the BOM app and should not be overridden. Anything that can be overriden should be in BASE_TEMPLATE, or base.html #}

{% block menu %}
    {% block bom-menu %}{% endblock %}
    {% include 'bom/bom-base-menu.html' %}
{% endblock %}

{% block menu-mobile %}
    {% block bom-menu-mobile %}{% endblock %}
    {% include 'bom/bom-base-menu.html' %}
{% endblock %}

{% block script %}
    <!-- materialize form select -->
    <script>
    $(document).ready(function () {
        $('select').formSelect();
        $('.sidenav').sidenav();
    });
    </script>
    {% block bom-script %}{% endblock %}
{% endblock script %}