# Generated by Django 2.1.5 on 2019-02-23 23:53

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('bom', '0013_auto_20190222_1631'),
    ]

    operations = [
        migrations.RenameField(
            model_name='partchangehistory',
            old_name='part_id',
            new_name='part',
        ),
    ]
