# Generated by Django 5.2.8 on 2026-01-04 00:59

import django.db.models.deletion
from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bom', '0050_alter_organization_options'),
        migrations.swappable_dependency(settings.BOM_ORGANIZATION_MODEL),
    ]

    operations = [
        migrations.AlterField(
            model_name='manufacturer',
            name='organization',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to=settings.BOM_ORGANIZATION_MODEL),
        ),
        migrations.AlterField(
            model_name='part',
            name='organization',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to=settings.BOM_ORGANIZATION_MODEL),
        ),
        migrations.AlterField(
            model_name='partclass',
            name='organization',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to=settings.BOM_ORGANIZATION_MODEL),
        ),
        migrations.AlterField(
            model_name='seller',
            name='organization',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to=settings.BOM_ORGANIZATION_MODEL),
        ),
        migrations.AlterField(
            model_name='usermeta',
            name='organization',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to=settings.BOM_ORGANIZATION_MODEL),
        ),
    ]
