# Generated by Django 5.2.8 on 2025-12-16 18:43

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('bom', '0049_alter_assembly_id_alter_assemblysubparts_id_and_more'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='organization',
            options={'permissions': (('manage_members', 'Can manage organization members'),)},
        ),
    ]
